
# Time definitions in seconds
MILLISECOND = 0.001
SECOND = 1
MINUTE = 60 * SECOND
HOUR = 60 * MINUTE

# Helpful times in seconds
ONE_HUNDRED_MILLISECONDS = 100 * MILLISECOND
FIVE_HUNDRED_MILLISECONDS = 500 * MILLISECOND
ONE_SECOND = SECOND
TWO_SECONDS = 2 * SECOND
FIVE_SECONDS = 5 * SECOND
TEN_SECONDS = 10 * SECOND
ONE_MINUTE = MINUTE
TWO_MINUTES = 2 * MINUTE
FIVE_MINUTES = 5 * MINUTE
TEN_MINUTES = 10 * MINUTE
